@@ -942,7 +942,7 @@ mod tests {
     };
     use crate::{
         nonce::sodiumoxide::{SodiumOxideAsymmetricNonce, SodiumOxideSymmetricNonce},
-        storage::tests::MockStorer,
+        storage::tests::MockStorer, storage::tests::MockIndexedStorer,
         Algorithm, AsymmetricKeyBuilder, BoolDataBuilder, Builder, ByteSource, Data, DataBuilder,
         HasBuilder, HasByteSource, HasIndex, HasPublicKey, KeyBuilder, PublicAsymmetricKeyBuilder,
         PublicAsymmetricSealer, PublicAsymmetricUnsealer, SecretAsymmetricKeyBuilder,
@@ -1218,11 +1218,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".encryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".encryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_key));
+            .return_once(move |_| Ok(unsealed_key));
         let ref_key = get_sosk()
             .to_ref_entry(".encryptionkey.".to_owned(), storer)
             .unwrap();
@@ -1269,11 +1269,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".keyencryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".keyencryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_key_encryption_key));
+            .return_once(move |_| Ok(unsealed_key_encryption_key));
         let data = Data::String("hello, world!".to_owned());
         let key = get_sosk();
         let referenced_key_encryption_key = get_sosk()
@@ -1326,11 +1326,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".encryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".encryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_key));
+            .return_once(move |_| Ok(unsealed_key));
         let ref_key = get_sosk()
             .to_ref_entry(".encryptionkey.".to_owned(), storer)
             .unwrap();
@@ -1383,11 +1383,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".keyencryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".keyencryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_key_encryption_key));
+            .return_once(move |_| Ok(unsealed_key_encryption_key));
         let data = Data::String("hello, world!".to_owned());
         let key = get_sosk();
         let referenced_key_encryption_key = get_sosk()
@@ -1561,14 +1561,13 @@ mod tests {
             .to_unsealed_entry(".bobpublickey.".to_owned())
             .unwrap();
         let bob_key_bytes = unsealed_bob_key.resolve().await.unwrap().byte_source();
-        let mut storer = MockStorer::new();
+        let mut storer = MockIndexedStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideCurve25519SecretAsymmetricKey>()
-            .withf(|path, index| {
+            .expect_private_get::<SodiumOxideCurve25519SecretAsymmetricKey>()
+            .withf(|path| {
                 path == ".alicesecretkey."
-                    && index == &SodiumOxideCurve25519SecretAsymmetricKey::get_index()
             })
-            .return_once(move |_, _| Ok(unsealed_alice_key));
+            .return_once(move |_| Ok(unsealed_alice_key));
         let ref_alice_key = get_sosak()
             .to_ref_entry(".alicesecretkey.".to_owned(), storer)
             .unwrap();
@@ -1630,11 +1629,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".alicedecryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".alicedecryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_alice_decryption_key));
+            .return_once(move |_| Ok(unsealed_alice_decryption_key));
         let ref_alice_decryption_key = get_sosk()
             .to_ref_entry(".alicedecryptionkey.".to_owned(), storer)
             .unwrap();
@@ -1713,12 +1712,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideCurve25519SecretAsymmetricKey>()
-            .withf(|path, index| {
+            .expect_private_get::<SodiumOxideCurve25519SecretAsymmetricKey>()
+            .withf(|path| {
                 path == ".alicesecretkey."
-                    && index == &SodiumOxideCurve25519SecretAsymmetricKey::get_index()
             })
-            .return_once(move |_, _| Ok(unsealed_alice_key));
+            .return_once(move |_| Ok(unsealed_alice_key));
         let ref_alice_key = get_sosak()
             .to_ref_entry(".alicesecretkey.".to_owned(), storer)
             .unwrap();
@@ -1783,11 +1781,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".alicedecryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".alicedecryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_alice_decryption_key));
+            .return_once(move |_| Ok(unsealed_alice_decryption_key));
         let ref_alice_decryption_key = get_sosk()
             .to_ref_entry(".alicedecryptionkey.".to_owned(), storer)
             .unwrap();
@@ -1975,12 +1973,11 @@ mod tests {
         let bob_key_bytes = unsealed_bob_key.resolve().await.unwrap().byte_source();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideCurve25519PublicAsymmetricKey>()
-            .withf(|path, index| {
+            .expect_private_get::<SodiumOxideCurve25519PublicAsymmetricKey>()
+            .withf(|path| {
                 path == ".alicepublickey."
-                    && index == &SodiumOxideCurve25519PublicAsymmetricKey::get_index()
             })
-            .return_once(move |_, _| Ok(unsealed_alice_public_key));
+            .return_once(move |_| Ok(unsealed_alice_public_key));
         let (alice_public_key, _) = get_sopak();
         let ref_alice_public_key = alice_public_key
             .to_ref_entry(".alicepublickey.".to_owned(), storer)
@@ -2042,11 +2039,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".alicedecryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".alicedecryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_alice_decryption_key));
+            .return_once(move |_| Ok(unsealed_alice_decryption_key));
         let ref_alice_decryption_key = get_sosk()
             .to_ref_entry(".alicedecryptionkey.".to_owned(), storer)
             .unwrap();
@@ -2122,12 +2119,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideCurve25519PublicAsymmetricKey>()
-            .withf(|path, index| {
+            .expect_private_get::<SodiumOxideCurve25519PublicAsymmetricKey>()
+            .withf(|path| {
                 path == ".alicepublickey."
-                    && index == &SodiumOxideCurve25519PublicAsymmetricKey::get_index()
             })
-            .return_once(move |_, _| Ok(unsealed_alice_public_key));
+            .return_once(move |_| Ok(unsealed_alice_public_key));
         let (alice_public_key, _) = get_sopak();
         let ref_alice_public_key = alice_public_key
             .to_ref_entry(".alicepublickey.".to_owned(), storer)
@@ -2192,11 +2188,11 @@ mod tests {
             .unwrap();
         let mut storer = MockStorer::new();
         storer
-            .expect_private_get_indexed::<SodiumOxideSymmetricKey>()
-            .withf(|path, index| {
-                path == ".alicedecryptionkey." && index == &SodiumOxideSymmetricKey::get_index()
+            .expect_private_get::<SodiumOxideSymmetricKey>()
+            .withf(|path| {
+                path == ".alicedecryptionkey."
             })
-            .return_once(move |_, _| Ok(unsealed_alice_decryption_key));
+            .return_once(move |_| Ok(unsealed_alice_decryption_key));
         let ref_alice_decryption_key = get_sosk()
             .to_ref_entry(".alicedecryptionkey.".to_owned(), storer)
             .unwrap();
